# Hoser-py

Hoser-py is a Python interface for describing Hoser pipelines. The goal is to make it as simple as writing a few lines of Python
to create a scalable data pipeline.

## Getting Started

Must have installed:
- Python 3
- Golang
- Hoser Runtime

## Developing Locally

Install with pip locally to run examples

```
python -m pip install -e .
```